@@ -744,6 +744,11 @@ arv_camera_get_frame_rate_bounds (ArvCamera *camera, double *min, double *max)
 {
 	ArvGcNode *feature;
 
+	if (min != NULL)
+		*min = G_MINDOUBLE;
+	if (max != NULL)
+		*max = G_MAXDOUBLE;
+
 	g_return_if_fail (ARV_IS_CAMERA (camera));
 
 	switch (camera->priv->vendor) {
@@ -755,11 +760,6 @@ arv_camera_get_frame_rate_bounds (ArvCamera *camera, double *min, double *max)
 				guint n_values;
 				guint i;
 
-				if (min != NULL)
-					*min = 0;
-				if (max != NULL)
-					*max = 0;
-
 				values = arv_gc_enumeration_get_available_int_values (ARV_GC_ENUMERATION (feature), &n_values, NULL);
 				for (i = 0; i < n_values; i++) {
 					if (values[i] > 0) {
@@ -767,9 +767,9 @@ arv_camera_get_frame_rate_bounds (ArvCamera *camera, double *min, double *max)
 
 						s = (int)((10000000/(double) values[i]) * 100 + 0.5) / 100.0;
 
-						if (s > *max && max != NULL)
+						if (max != NULL && s > *max)
 							*max = s;
-						if ((*min == 0 || *min > s) && min != NULL)
+						if (min != NULL && (*min == 0 || *min > s))
 							*min = s;
 					}
 				}
@@ -1304,9 +1304,10 @@ arv_camera_new (const char *name)
 
 	camera = g_object_new (ARV_TYPE_CAMERA, "device", device, NULL);
 
-	camera->priv->use_gain_raw = !ARV_IS_GC_FLOAT (arv_device_get_feature (device, "Gain"));
-	camera->priv->use_exposure_time_abs = !ARV_IS_GC_FLOAT (arv_device_get_feature (device, "ExposureTime"));
-	camera->priv->use_acquisition_frame_rate_abs = !ARV_IS_GC_FLOAT (arv_device_get_feature (device, "AcquisitionFrameRate"));
+    /* if you need to apply or test for fixups based on the camera model
+       please do so in arv_camera_constructor and not here, as this breaks
+       objects created with g_object_new, which includes but is not limited to
+       introspection users */
 
 	return camera;
 }
@@ -1378,6 +1379,10 @@ arv_camera_constructor (GType gtype, guint n_properties, GObjectConstructParam *
 	camera->priv->vendor = vendor;
 	camera->priv->series = series;
 
+	camera->priv->use_gain_raw = !ARV_IS_GC_FLOAT (arv_device_get_feature (camera->priv->device, "Gain"));
+	camera->priv->use_exposure_time_abs = !ARV_IS_GC_FLOAT (arv_device_get_feature (camera->priv->device, "ExposureTime"));
+	camera->priv->use_acquisition_frame_rate_abs = !ARV_IS_GC_FLOAT (arv_device_get_feature (camera->priv->device, "AcquisitionFrameRate"));
+
     return object;
 }
 
