@@ -109,8 +109,15 @@ typedef guint32 ArvPixelFormat;
 #define ARV_PIXEL_FORMAT_BAYER_BG_12		0x01100013
 
 #define ARV_PIXEL_FORMAT_BAYER_GR_12_PACKED	0x010c002a
+#define ARV_PIXEL_FORMAT_BAYER_RG_12_PACKED	0x010c002b
+#define ARV_PIXEL_FORMAT_BAYER_GB_12_PACKED	0x010c002c
 #define ARV_PIXEL_FORMAT_BAYER_BG_12_PACKED	0x010c002d
 
+#define ARV_PIXEL_FORMAT_BAYER_GR_16		0x0110002e
+#define ARV_PIXEL_FORMAT_BAYER_RG_16		0x0110002f
+#define ARV_PIXEL_FORMAT_BAYER_GB_16		0x01100030
+#define ARV_PIXEL_FORMAT_BAYER_BG_16		0x01100031
+
 /* Color pixel formats */
 
 #define ARV_PIXEL_FORMAT_RGB_8_PACKED		0x02180014
