@@ -44,7 +44,6 @@
 
 typedef struct {
 	GSocketAddress *interface_address;
-	GSocketAddress *broadcast_address;
 	GSocket *socket;
 } ArvGvDiscoverSocket;
 
@@ -84,6 +83,7 @@ arv_gv_discover_socket_list_new (void)
 	for (ifap_iter = ifap; ifap_iter != NULL; ifap_iter = ifap_iter->ifa_next) {
 		if ((ifap_iter->ifa_flags & IFF_UP) != 0 &&
 		    (ifap_iter->ifa_flags & IFF_POINTOPOINT) == 0 &&
+		    (ifap_iter->ifa_addr != NULL) &&
 		    (ifap_iter->ifa_addr->sa_family == AF_INET)) {
 			ArvGvDiscoverSocket *discover_socket = g_new0 (ArvGvDiscoverSocket, 1);
 			GSocketAddress *socket_address;
@@ -100,15 +100,6 @@ arv_gv_discover_socket_list_new (void)
 			discover_socket->interface_address = g_inet_socket_address_new (inet_address, 0);
 			g_object_unref (socket_address);
 
-			socket_address = g_socket_address_new_from_native (ifap_iter->ifa_broadaddr,
-									   sizeof (struct sockaddr));
-			inet_address = g_inet_socket_address_get_address (G_INET_SOCKET_ADDRESS (socket_address));
-			discover_socket->broadcast_address = g_inet_socket_address_new (inet_address, ARV_GVCP_PORT);
-			inet_address_string = g_inet_address_to_string (inet_address);
-			arv_debug_interface ("[GvDiscoverSocket::new] Broadcast address is %s", inet_address_string);
-			g_free (inet_address_string);
-			g_object_unref (socket_address);
-
 			discover_socket->socket = g_socket_new (G_SOCKET_FAMILY_IPV4,
 								G_SOCKET_TYPE_DATAGRAM,
 								G_SOCKET_PROTOCOL_UDP, NULL);
@@ -144,7 +135,6 @@ arv_gv_discover_socket_list_free (ArvGvDiscoverSocketList *socket_list)
 		ArvGvDiscoverSocket *discover_socket = iter->data;
 
 		g_object_unref (discover_socket->interface_address);
-		g_object_unref (discover_socket->broadcast_address);
 		g_object_unref (discover_socket->socket);
 		g_free (discover_socket);
 	}
@@ -161,19 +151,25 @@ arv_gv_discover_socket_list_free (ArvGvDiscoverSocketList *socket_list)
 static void
 arv_gv_discover_socket_list_send_discover_packet (ArvGvDiscoverSocketList *socket_list)
 {
+	GInetAddress *broadcast_address;
+	GSocketAddress *broadcast_socket_address;
 	ArvGvcpPacket *packet;
 	GSList *iter;
 	size_t size;
 
 	packet = arv_gvcp_packet_new_discovery_cmd (&size);
 
+	broadcast_address = g_inet_address_new_from_string ("255.255.255.255");
+	broadcast_socket_address = g_inet_socket_address_new (broadcast_address, ARV_GVCP_PORT);
+	g_object_unref (broadcast_address);
+
 	for (iter = socket_list->sockets; iter != NULL; iter = iter->next) {
 		ArvGvDiscoverSocket *discover_socket = iter->data;
 		GError *error = NULL;
 
 		arv_gv_discover_socket_set_broadcast (discover_socket, TRUE);
 		g_socket_send_to (discover_socket->socket,
-				  discover_socket->broadcast_address,
+				  broadcast_socket_address,
 				  (const char *) packet, size,
 				  NULL, &error);
 		if (error != NULL) {
@@ -183,6 +179,8 @@ arv_gv_discover_socket_list_send_discover_packet (ArvGvDiscoverSocketList *socke
 		arv_gv_discover_socket_set_broadcast (discover_socket, FALSE);
 	}
 
+	g_object_unref (broadcast_socket_address);
+
 	arv_gvcp_packet_free (packet);
 }
 
@@ -335,16 +333,16 @@ arv_gv_interface_discover (ArvGvInterface *gv_interface)
 
 						if (device_infos->name != NULL && device_infos->name[0] != '\0') {
 							arv_gv_interface_device_infos_ref (device_infos);
-							g_hash_table_insert (gv_interface->priv->devices,
+							g_hash_table_replace (gv_interface->priv->devices,
 									     device_infos->name, device_infos);
 						}
 						if (device_infos->user_name != NULL && device_infos->user_name[0] != '\0') {
 							arv_gv_interface_device_infos_ref (device_infos);
-							g_hash_table_insert (gv_interface->priv->devices,
+							g_hash_table_replace (gv_interface->priv->devices,
 									     device_infos->user_name, device_infos);
 						}
 						arv_gv_interface_device_infos_ref (device_infos);
-						g_hash_table_insert (gv_interface->priv->devices, device_infos->mac_string, device_infos);
+						g_hash_table_replace (gv_interface->priv->devices, device_infos->mac_string, device_infos);
 
 						arv_gv_interface_device_infos_unref (device_infos);
 					}
